<?php

namespace FiloBlu\ScratchAndWin\Setup;

use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

class InstallSchema implements InstallSchemaInterface
{

    /**
     * {@inheritdoc}
     */
    public function install(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $installer = $setup;
        $installer->startSetup();

        /**
         * Create table 'filoblu_scratchandwin'
         */
        if (!$installer->tableExists('filoblu_scratchandwin')) {
            $table = $installer->getConnection()->newTable(
                $installer->getTable('filoblu_scratchandwin'))
                ->addColumn('id', \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER, null,
                    [
                        'identity' => true,
                        'nullable' => false,
                        'primary' => true
                    ], 'ID'
                )
                ->addColumn(
                    'enabled', \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT, null,
                    [
                        'nullable' => false,
                        'default' => '0'
                    ], 'Enabled'
                )
                ->addColumn(
                    'code', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 20, [
                    'nullable' => false,
                ], 'Code'
                )
                ->addColumn('description', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Description'
                )
                ->addColumn(
                    'bg_image', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'BG Image'
                )
                ->addColumn(
                    'bg_image_mobile', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'BG Image Mobile'
                )
                ->addColumn(
                    'bg_video', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'BG Video'
                )
                ->addColumn('custom_style', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Custom Style'
                )
                ->setComment('FiloBlu ScratchAndWin Table');

            $installer->getConnection()->createTable($table);
        }

        if (!$installer->tableExists('filoblu_scratchandwin_translations')) {
            $table = $installer->getConnection()->newTable(
                $installer->getTable('filoblu_scratchandwin_translations'))
                ->addColumn('id', \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER, null,
                    [
                        'identity' => true,
                        'nullable' => false,
                        'primary' => true
                    ], 'ID'
                )
                ->addColumn(
                    'filoblu_scratchandwin_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'nullable' => false
                    ],
                    'FiloBlu ScratchAndWin Id'
                )
                ->addColumn('serialized_values', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [
                        'nullable' => false
                    ], 'Serialized Values'
                )
                ->addColumn(
                    'store_id', \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT, null,
                    [
                        'nullable' => false,
                        'unsigned' => true
                    ], 'Store ID'
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandwin_translations', ['filoblu_scratchandwin_id']),
                    ['filoblu_scratchandwin_id']
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandwin_translations', ['store_id']),
                    ['store_id']
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandwin_translations',
                        'filoblu_scratchandwin_id',
                        'filoblu_scratchandwin',
                        'id'
                    ),
                    'filoblu_scratchandwin_id',
                    $setup->getTable('filoblu_scratchandwin'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandwin_translations',
                        'store_id',
                        'store',
                        'store_id'
                    ),
                    'store_id',
                    $setup->getTable('store'),
                    'store_id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addIndex(
                    $setup->getIdxName(
                        'filoblu_scratchandwin_translations',
                        [
                            'filoblu_scratchandwin_id',
                            'store_id'
                        ],
                        \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ),
                    [
                        'filoblu_scratchandwin_id',
                        'store_id'
                    ],
                    [
                        'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ]
                )
                ->setComment('FiloBlu ScratchAndWin Translations Table');

            $installer->getConnection()->createTable($table);
        }

        /**
         * Create table 'filoblu_scratchandwin_details'
         */
        if (!$installer->tableExists('filoblu_scratchandwin_details')) {
            $table = $installer->getConnection()->newTable(
                $installer->getTable('filoblu_scratchandwin_details'))
                ->addColumn('id', \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER, null,
                    [
                        'identity' => true,
                        'nullable' => false,
                        'primary' => true
                    ], 'ID'
                )
                ->addColumn(
                    'enabled', \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT, null,
                    [
                        'nullable' => false,
                        'default' => '0'
                    ], 'Enabled'
                )
                ->addColumn('short_display_text', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Short Display Text'
                )
                ->addColumn('long_display_text', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Long Display Text'
                )
                ->addColumn(
                    'overlay_image', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'Overlay Image'
                )
                ->addColumn(
                    'bg_image', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'BG Image'
                )
                ->addColumn(
                    'promocode', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 20, [], 'Promocode'
                )
                ->addColumn(
                    'cta_link', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'CTA link'
                )
                ->addColumn(
                    'final_date', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 10, [
                    'nullable' => false,
                ], 'Final Date'
                )
                ->addColumn(
                    'final_time', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 8, [
                    'nullable' => false,
                ], 'Final Time'
                )
                ->setComment('FiloBlu ScratchAndWin Table Details');

            $installer->getConnection()->createTable($table);
        }

        if (!$installer->tableExists('filoblu_scratchandwin_details_translations')) {
            $table = $installer->getConnection()->newTable(
                $installer->getTable('filoblu_scratchandwin_details_translations'))
                ->addColumn('id', \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER, null,
                    [
                        'identity' => true,
                        'nullable' => false,
                        'primary' => true
                    ], 'ID'
                )
                ->addColumn(
                    'filoblu_scratchandwin_details_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'nullable' => false
                    ],
                    'FiloBlu ScratchAndWin Details Id'
                )
                ->addColumn('serialized_values', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [
                        'nullable' => false
                    ], 'Serialized Values'
                )
                ->addColumn(
                    'store_id', \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT, null,
                    [
                        'nullable' => false,
                        'unsigned' => true
                    ], 'Store ID'
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandwin_details_translations', ['filoblu_scratchandwin_details_id']),
                    ['filoblu_scratchandwin_details_id']
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandwin_details_translations', ['store_id']),
                    ['store_id']
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandwin_details_translations',
                        'filoblu_scratchandwin_details_id',
                        'filoblu_scratchandwin_details',
                        'id'
                    ),
                    'filoblu_scratchandwin_details_id',
                    $setup->getTable('filoblu_scratchandwin_details'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandwin_details_translations',
                        'store_id',
                        'store',
                        'store_id'
                    ),
                    'store_id',
                    $setup->getTable('store'),
                    'store_id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addIndex(
                    $setup->getIdxName(
                        'filoblu_scratchandwin_details_translations',
                        [
                            'filoblu_scratchandwin_details_id',
                            'store_id'
                        ],
                        \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ),
                    [
                        'filoblu_scratchandwin_details_id',
                        'store_id'
                    ],
                    [
                        'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ]
                )
                ->setComment('FiloBlu ScratchAndWin Details Translations Table');

            $installer->getConnection()->createTable($table);
        }

        /**
         * Create table 'filoblu_scratchandwin_relations'
         */
        if (!$setup->tableExists('filoblu_scratchandwin_relations')) {
            $table = $setup->getConnection()
                ->newTable($setup->getTable('filoblu_scratchandwin_relations'));
            $table->addColumn(
                'filoblu_scratchandwin_id',
                \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                null,
                [
                    'nullable' => false,
                    'primary' => true,
                ],
                'FiloBlu ScratchAndWin Id'
                )
                ->addColumn(
                    'filoblu_scratchandwin_details_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'nullable' => false,
                        'primary' => true,
                    ],
                    'FiloBlu ScratchAndWin Details Id'
                )
                ->addColumn(
                    'position',
                    \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT,
                    null,
                    [
                        'nullable' => false,
                        'default' => '0'
                    ],
                    'Position'
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandwin_relations', ['filoblu_scratchandwin_id']),
                    ['filoblu_scratchandwin_id']
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandwin_relations', ['filoblu_scratchandwin_details_id']),
                    ['filoblu_scratchandwin_details_id']
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandwin_relations',
                        'filoblu_scratchandwin_id',
                        'filoblu_scratchandwin',
                        'id'
                    ),
                    'filoblu_scratchandwin_id',
                    $setup->getTable('filoblu_scratchandwin'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandwin_relations',
                        'filoblu_scratchandwin_details_id',
                        'filoblu_scratchandwin_details',
                        'id'
                    ),
                    'filoblu_scratchandwin_details_id',
                    $setup->getTable('filoblu_scratchandwin_details'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addIndex(
                    $setup->getIdxName(
                        'filoblu_scratchandwin_relations',
                        [
                            'filoblu_scratchandwin_id',
                            'filoblu_scratchandwin_details_id'
                        ],
                        \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ),
                    [
                        'filoblu_scratchandwin_id',
                        'filoblu_scratchandwin_details_id'
                    ],
                    [
                        'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ]
                )
                ->setComment('FiloBlu ScratchAndWin Link Table');
            $setup->getConnection()->createTable($table);
        }

        $installer->endSetup();
    }
}
